syntax = "proto3";


enum OperationType {
  SET = 0;
  DELETE = 1;
}

message State {
  uint32 proto_version = 1;
  bytes key = 2;
  optional OperationType operation_type = 3;
  uint64 seq_number = 4;
  optional bytes data = 5;
}
